# -*- coding: utf-8 -*-
# @Time    : 2022-11-29 20:45
# @Author  : MR.
# @Software: PyCharm


class MySDK():
    def __init__(self):
        pass

    def getsome(self):
        print("你好，这是一个测试包")


if __name__ == '__main__':
    runapp = MySDK()
    runapp.getsome()
